==> bdfn-1.0.11.tgz: package/src/client/base.js <==
const Discord = require('discord.js-light');
const { readdirSync } = require('fs');
const path = require('path');

module.exports = {
    create: async (token = String, cache = {}, intents, partials, shards = false) => {
        Discord._client = new Discord.Client({
            shards: shards? 'auto' : 0,
            makeCache: Discord.Options.cacheWithLimits(cache),
            intents: intents ?? [
                Discord.Intents.FLAGS.GUILDS,
                "DIRECT_MESSAGES",
                "GUILDS",
                "GUILD_EMOJIS_AND_STICKERS",
                "GUILD_INTEGRATIONS",
                "GUILD_INVITES", 
                "GUILD_MESSAGES",
                "GUILD_WEBHOOKS"
            ],
            partials: partials ?? [
                'CHANNEL',
                'GUILD_SCHEDULED_EVENT',
                'REACTION',
                'USER'
            ]
        });

        await Discord._client.login(token);
        return Discord._client;
    },

    destroy: async () => {
        Discord._client.destroy();
    },

    getClient: async () => {
        return Discord._client;
    },

    on: async (eventName = String, callback) => {
        Discord._client.on(eventName, callback);
    },

    setEventHandler: async (route = String) => {
        for(let event of readdirSync(path.join(__dirname, '../../../../' + route))) {
            require(path.join(__dirname, '../../../../' + route + event));
        }
    },

    setCommandHandler: async (route = String, withCategories = Boolean) => {
        for(let command of readdirSync(path.join(__dirname, '../../../../' + route))) {
            if((withCategories && !command.endsWith('.js') || (!withCategories && command.endsWith('.js')))) {
                if(withCategories) {
                    for(let parent of readdirSync(path.join(__dirname, '../../../../' + route))) {
                        if(parent.endsWith('.js')) {
                            require(path.join(__dirname, '../../../../' + route + command + '/' + parent));
                        }
                    }
                }else require(path.join(__dirname, '../../../../' + route + command));
            }
        }
    },
};

==> bdfn-1.1.0.tgz: package/src/client/base.js <==
const Discord = require('discord.js');
const { readdirSync } = require('fs');
const path = require('path');

module.exports = {
    create: async (token = String, cache = {}, intents, partials, shards = false) => {
        Discord._client = new Discord.Client({
            shards: shards? 'auto' : 0,
            makeCache: Discord.Options.cacheWithLimits(cache),
            intents: intents ?? [
                Discord.IntentsBitField.Flags.DirectMessages,
                Discord.IntentsBitField.Flags.Guilds,
                Discord.IntentsBitField.Flags.GuildEmojisAndStickers,
                Discord.IntentsBitField.Flags.GuildIntegrations,
                Discord.IntentsBitField.Flags.GuildInvites,
                Discord.IntentsBitField.Flags.GuildMessages,
                Discord.IntentsBitField.Flags.GuildWebhooks
            ],
            partials: partials ?? [
                Discord.Partials.Channel,
                Discord.Partials.GuildMember,
                Discord.Partials.GuildScheduledEvent,
                Discord.Partials.Message,
                Discord.Partials.Reaction,
                Discord.Partials.ThreadMember,
                Discord.Partials.User
            ]
        });

        await Discord._client.login(token);
        return Discord._client;
    },

    destroy: async () => {
        Discord._client.destroy();
    },

    getClient: async () => {
        return Discord._client;
    },

    on: async (eventName = String, callback) => {
        Discord._client.on(eventName, callback);
    },

    setEventHandler: async (route = String) => {
        for(let event of readdirSync(path.join(__dirname, '../../../../' + route))) {
            require(path.join(__dirname, '../../../../' + route + event));
        }
    },

    setCommandHandler: async (route = String, withCategories = Boolean) => {
        for(let command of readdirSync(path.join(__dirname, '../../../../' + route))) {
            if((withCategories && !command.endsWith('.js') || (!withCategories && command.endsWith('.js')))) {
                if(withCategories) {
                    for(let parent of readdirSync(path.join(__dirname, '../../../../' + route))) {
                        if(parent.endsWith('.js')) {
                            require(path.join(__dirname, '../../../../' + route + command + '/' + parent));
                        }
                    }
                }else require(path.join(__dirname, '../../../../' + route + command));
            }
        }
    },
};
